{pkgs', ...}: let
in
  pkgs'.writeShellScriptBin "update-project" ''
    source ${pkgs'.common}/bin/common

    echo_section "Update project"
    echo_hint "This script will update the project by formatting the code and installing dependencies."
    echo_hint "The command is executed in the current working directory and not in a nix derivation."
    cd_working_dir

    echo_step "Checking nix code"
    if ! ${pkgs'.alejandra}/bin/alejandra flake.nix ./nix/scripts/*.nix ./nix/config/*.nix ./nix/packages/*nix
    then
      echo_fail "alejandra formatting failed"
      exit 1
    else
      echo_ok "nix code formatted"
    fi

    echo_step "Installing dependencies (node)"

    if ! ${pkgs'.findutils}/bin/find . -type d -name node_modules -prune -o -type f -name package.json -print | ${pkgs'.findutils}/bin/xargs -I {} sh -c "cd $(dirname {}); ${pkgs'.projectCorepack}/bin/npm install"
    then
      echo_error "Failed to install dependencies"
      echo_hint "Check the error message and try again"
      exit 1
    fi

    ## update monser.mjs
    echo_step "Updating monser.mjs"
    if ! ${pkgs'.projectNodeJS}/bin/node "./development/scripts/buildMonsterFile.mjs"
    then
        echo_fail "Failed to update monser.mjs"
        exit 1
    fi

    ##format javascript code
    echo_step "Formatting JS code"
    if ! ${pkgs'.biome}/bin/biome format --write ./source/
    then
      echo_fail "biome format failed"
      exit 1
    else
        echo_ok "JS code formatted"
    fi

    ## lint javascript code
    echo_step "Linting JS code"
    if ! ${pkgs'.biome}/bin/biome lint ./source/
    then
      echo_fail "biome lint failed"
      # exit 1  # to many errors, therefore not exiting
      echo_hint "we do not exit the script here, because the linting still results in too many issues that need to be fixed bit by bit."
      echo_hint "check one or two places and reduce the number, please. ♥"
    fi

    echo_ok "Code checked"
  ''
